import os
import numpy
from matplotlib import pyplot
from scipy.stats import ttest_rel

# Auto-detect the data folder
dirname = os.path.dirname( \
    os.path.abspath(__file__))
datadir = os.path.join(dirname, 'data')
# Throw an error if there is no data folder
if not os.path.isdir(datadir):
    raise Exception("Data folder not found.")

# Get the first data file
all_files = os.listdir(datadir)
filename = all_files[0]
filepath = os.path.join(datadir, filename)
# Raise an exception if the file doesn't exist
if not os.path.isfile(filepath):
    raise Exception("File not found!")

# Load the data (FINALLY!)
raw = numpy.loadtxt( \
    filepath, \
    dtype=str, \
    unpack=True, \
    delimiter='\t')

# Convert the raw data into a sensible format
data = {}
# Find the number of columns
ncol = len(raw)
for i in range(ncol):
    varname = raw[i][0]
    values = raw[i][1:]
    try:
        data[varname] = values.astype(float)
    except ValueError:
        data[varname] = values

valid = data['valid'] == 1
invalid = data['valid'] == 0

print 'valid: ', data['RT'][valid].mean()
print 'invalid: ', data['RT'][invalid].mean()

