import random

from constants import *
from pygaze.display import Display
from pygaze.screen import Screen
from pygaze.keyboard import Keyboard
from pygaze.logfile import Logfile
import pygaze.libtime as timer

# Create a new Display
disp = Display()
# Create a new Keyboard
kb = Keyboard(keylist=None, \
    timeout=None)
# Open a new logfile
log = Logfile()
log.write(['trialnr', \
    'fixonset', 'cueonset', 'cueoffset', \
    'taronset', 'taroffset',
    'soa', 'cueside', 'tarside', 'target', 'valid', \
    'response', 'RT', 'correct'])

# Define instructions
instructions = "These are instructions"

# Create a new Screen for the instructions
instscr = Screen()
# Draw the instructions on the Screen
instscr.draw_text(text=instructions, \
    fontsize=24)

# Create a new Screen with a fixation mark
fixscr = Screen()
fixscr.draw_fixation(fixtype='cross', \
    diameter=12, pw=3)
# Add the boxes to the fixation screen
for side in BOXCORS.keys():
    fixscr.draw_rect( \
        x=BOXCORS[side][0], \
        y=BOXCORS[side][1], \
        w=BOXSIZE, \
        h=BOXSIZE, \
        pw=3,
        fill=False)

# Generate the cue Screens
cuescr = {}
for side in BOXCORS.keys():
    cuescr[side] = Screen()

    cuescr[side].copy(fixscr)
    cuescr[side].draw_rect( \
        x=BOXCORS[side][0], \
        y=BOXCORS[side][1], \
        w=BOXSIZE, \
        h=BOXSIZE, \
        pw=8,
        fill=False)

# Generate the target Screens
tarscr = {}
for side in BOXCORS.keys():
    tarscr[side] = {}
    for target in TARGETS:
        tarpos = ( \
            int(BOXCORS[side][0] + BOXSIZE/2),
            int(BOXCORS[side][1] + BOXSIZE/2))
        tarscr[side][target] = Screen()
        tarscr[side][target].copy(fixscr)
        tarscr[side][target].draw_text( \
            pos=tarpos, \
            text=target, \
            fontsize=48)

# Generate feedback screens
fbscr = {}
# Draw the feedback for correct responses
fbscr[1] = Screen()
fbscr[1].draw_text(text='Correct!', \
    colour=(0, 255, 0), \
    fontsize=24)
# Draw the feedback for incorrect responses
fbscr[0] = Screen()
fbscr[0].draw_text(text='Incorrect!', \
    colour=(255, 0, 0), \
    fontsize=24)


# Present instructions
disp.fill(instscr)
disp.show()
# Wait for a Space press.
kb.get_key( \
    keylist=['space'], \
    timeout=None, \
    flush=True)

# Generate trials
trials = []
for target in TARGETS:
    for cueside in CUELOCS:
        for tarside in TARLOCS:
            for soa in SOAS:
                for i in range(TRIALSPERCELL):

                    t = { \
                        'target':target, \
                        'tarside':tarside, \
                        'cueside':cueside, \
                        'soa':soa \
                        }
                    trials.append(t)
# Randomise trials
random.shuffle(trials)                
                
# Run through all trials
for trialnr, trial in enumerate(trials):
    
    # Convenience renaming
    target = trial['target']
    tarside = trial['tarside']
    cueside = trial['cueside']
    soa = trial['soa']

    # Present fixation screen
    disp.fill(fixscr)
    fixonset = disp.show()
    timer.pause(FIXTIME - 8)
    
    # Present cue!
    disp.fill(cuescr[cueside])
    cueonset = disp.show()
    timer.pause(CUETIME - 8)
    
    # Bring the fixation back
    disp.fill(fixscr)
    cueoffset = disp.show()
    
    # Wait for the SOA
    timer.pause(soa - CUETIME - 8)
    
    # Show the target!
    disp.fill(tarscr[tarside][target])
    taronset = disp.show()
    
    # Wait for a response.
    key, presstime = kb.get_key( \
        keylist=LCTARGETS, \
        timeout=None, \
        flush=True)
    
    # Determine the feedback.
    if key is None:
        correct = 0
    elif key.upper() == target:
        correct = 1
    else:
        correct = 0
    
    # Determine the validity
    valid = int(cueside == tarside)
    
    # Calculate the response time
    rt = presstime - taronset
    
    # Show them feedbackz
    disp.fill(fbscr[correct])
    taroffset = disp.show()
    timer.pause(FEEDBACKTIME - 8)
    
    # Update the log file
    log.write([trialnr, \
        fixonset, cueonset, cueoffset, \
        taronset, taroffset,
        soa, cueside, tarside, target, valid, \
        key.upper(), rt, correct])


# Close down the experiment.
log.close()
disp.close()
